Installation
============

Download and install ``django-pages-cms-extensions`` using **one** of the following methods:

PIP
---

You can install the latest stable package running this command::

    $ pip install django-pages-cms-extensions

Also you can install the development version running this command::

    $ pip install -e git+http://github.com/dlancer/django-pages-cms-extensions.git#egg=extpages-dev


Setuptools
----------

You can install the latest stable package running::

    $ easy_install django-pages-cms-extensions


